@@ -123,24 +123,31 @@ private:
   Lum::Base::SystemTime  fixLastData;
 
   double                 latitude;
+  double                 latitudeDev;
   Lum::Base::SystemTime  latitudeLastData;
 
   double                 longitude;
+  double                 longitudeDev;
   Lum::Base::SystemTime  longitudeLastData;
 
   double                 altitude;
+  double                 altitudeDev;
   Lum::Base::SystemTime  altitudeLastData;
 
   double                 speed;
+  double                 speedDev;
   Lum::Base::SystemTime  speedLastData;
 
   double                 track;
+  double                 trackDev;
   Lum::Base::SystemTime  trackLastData;
 
   double                 climb;
+  double                 climbDev;
   Lum::Base::SystemTime  climbLastData;
 
   Lum::Base::SystemTime  time;
+  double                 timeDev;
   Lum::Base::SystemTime  timeLastData;
 
   std::vector<Satellite> satellites;
@@ -235,10 +242,12 @@ public:
   //
   // Latitude
   //
-  void SetLatitude(double latitude)
+  void SetLatitude(double latitude,
+                   double latitudeDev)
   {
     latitudeLastData.SetToNow();
     this->latitude=latitude;
+    this->latitudeDev=latitudeDev;
   }
 
   bool HasLatitude() const
@@ -255,13 +264,22 @@ public:
     return latitude;
   }
 
+  double GetLatitudeDev() const
+  {
+    assert(HasLatitude());
+
+    return latitudeDev;
+  }
+
   //
   // Longitude
   //
-  void SetLongitude(double longitude)
+  void SetLongitude(double longitude,
+                    double longitudeDev)
   {
     longitudeLastData.SetToNow();
     this->longitude=longitude;
+    this->longitudeDev=longitudeDev;
   }
 
   bool HasLongitude() const
@@ -278,13 +296,22 @@ public:
     return longitude;
   }
 
+  double GetLongitudeDev() const
+  {
+    assert(HasLongitude());
+
+    return longitudeDev;
+  }
+
   //
   // Altitude
   //
-  void SetAltitude(double altitude)
+  void SetAltitude(double altitude,
+                   double altitudeDev)
   {
     altitudeLastData.SetToNow();
     this->altitude=altitude;
+    this->altitudeDev=altitudeDev;
   }
 
   bool HasAltitude() const
@@ -301,13 +328,22 @@ public:
     return altitude;
   }
 
+  double GetAltitudeDev() const
+  {
+    assert(HasAltitude());
+
+    return altitudeDev;
+  }
+
   //
   // Speed
   //
-  void SetSpeed(double speed)
+  void SetSpeed(double speed,
+                double speedDev)
   {
     speedLastData.SetToNow();
     this->speed=speed;
+    this->speedDev=speedDev;
   }
 
   bool HasSpeed() const
@@ -324,13 +360,22 @@ public:
     return speed;
   }
 
+  double GetSpeedDev() const
+  {
+    assert(HasSpeed());
+
+    return speedDev;
+  }
+
   //
   // Track
   //
-  void SetTrack(double track)
+  void SetTrack(double track,
+                double trackDev)
   {
     trackLastData.SetToNow();
     this->track=track;
+    this->trackDev=trackDev;
   }
 
   bool HasTrack() const
@@ -347,13 +392,22 @@ public:
     return track;
   }
 
+  double GetTrackDev() const
+  {
+    assert(HasTrack());
+
+    return trackDev;
+  }
+
   //
   // Climb
   //
-  void SetClimb(double climb)
+  void SetClimb(double climb,
+                double climbDev)
   {
     climbLastData.SetToNow();
     this->climb=climb;
+    this->climbDev=climbDev;
   }
 
   bool HasClimb() const
@@ -370,13 +424,22 @@ public:
     return climb;
   }
 
+  double GetClimbDev() const
+  {
+    assert(HasClimb());
+
+    return climbDev;
+  }
+
   //
   // Time
   //
-  void SetTime(Lum::Base::SystemTime& time)
+  void SetTime(Lum::Base::SystemTime& time,
+               double timeDev)
   {
     timeLastData.SetToNow();
     this->time=time;
+    this->timeDev=timeDev;
   }
 
   bool HasTime() const
@@ -393,6 +456,13 @@ public:
     return time;
   }
 
+  double GetTimeDev() const
+  {
+    assert(HasTime());
+
+    return timeDev;
+  }
+
   //
   // Satellites
   //
@@ -1565,48 +1635,102 @@ public:
     }
 
     if (data.HasTime()) {
-      time->Set(data.GetTime().GetLocalLocaleDateTime());
+      std::wstring t=data.GetTime().GetLocalLocaleDateTime();
+
+      if (data.GetTimeDev()!=0) {
+        t+=L"\u00b1"+DoubleToString(data.GetTimeDev());
+      }
+
+      time->Set(t);
     }
     else {
       time->SetNull();
     }
 
     if (data.HasLatitude()) {
-      latitude->Set(DoubleToString(data.GetLatitude())+L"\u00b0");
+      std::wstring l=DoubleToString(data.GetLatitude());
+
+      if (data.GetLatitudeDev()!=0) {
+        l+=L"\u00b1"+DoubleToString(data.GetLatitudeDev());
+      }
+
+      l+=+L"\u00b0";
+
+      latitude->Set(l);
     }
     else {
       latitude->SetNull();
     }
 
     if (data.HasLongitude()) {
-      longitude->Set(DoubleToString(data.GetLongitude())+L"\u00b0");
+      std::wstring l=DoubleToString(data.GetLongitude());
+
+      if (data.GetLongitudeDev()!=0) {
+        l+=L"\u00b1"+DoubleToString(data.GetLongitudeDev());
+      }
+
+      l+=+L"\u00b0";
+
+      longitude->Set(l);
     }
     else {
       longitude->SetNull();
     }
 
     if (data.HasAltitude()) {
-      altitude->Set(DoubleToString(data.GetAltitude())+L"m");
+      std::wstring a=DoubleToString(data.GetAltitude());
+
+      if (data.GetAltitudeDev()!=0) {
+        a+=L"\u00b1"+DoubleToString(data.GetAltitudeDev());
+      }
+
+      a+=L"m";
+
+      altitude->Set(a);
     }
     else {
       altitude->SetNull();
     }
 
     if (data.HasSpeed()) {
+      std::wstring s;
       // We expect m/s here
       if (data.GetSpeed()>=1/3.6) {
-        speed->Set(DoubleToString(data.GetSpeed()*3600.0/1000)+L"km/h");
+        s=DoubleToString(data.GetSpeed()*3600.0/1000);
+
+        if (data.GetSpeedDev()!=0) {
+          s+=L"\u00b1"+DoubleToString(data.GetSpeedDev()*3600.0/1000);
+        }
+
+        s+=L"km/h";
       }
       else {
-        speed->Set(DoubleToString(data.GetSpeed())+L"m/s");
+        s=DoubleToString(data.GetSpeed());
+
+        if (data.GetSpeedDev()!=0) {
+          s+=L"\u00b1"+DoubleToString(data.GetSpeedDev());
+        }
+
+        s+=L"m/s";
       }
+
+      speed->Set(s);
     }
     else {
       speed->SetNull();
     }
 
     if (data.HasTrack()) {
-      track->Set(DoubleToString(data.GetTrack())+L"\u00b0");
+      std::wstring t=DoubleToString(data.GetTrack());
+
+      if (data.GetTrackDev()!=0) {
+        t+=L"\u00b1"+DoubleToString(data.GetTrackDev());
+      }
+
+      t+=+L"\u00b0";
+
+      track->Set(t);
+
       direction->Set(data.GetTrack());
     }
     else {
@@ -1615,7 +1739,15 @@ public:
     }
 
     if (data.HasClimb()) {
-      climb->Set(DoubleToString(data.GetClimb())+L"m");
+      std::wstring c=DoubleToString(data.GetClimb());
+
+      if (data.GetClimbDev()!=0) {
+        c+=L"\u00b1"+DoubleToString(data.GetClimbDev());
+      }
+
+      c+=+L"m";
+
+      climb->Set(c);
     }
     else {
       climb->SetNull();
@@ -1785,32 +1917,32 @@ static void cb(struct gps_data_t* data, char * buf, size_t len, int level)
   }
 
   if ((data->set & LATLON_SET)  && !isnan(data->fix.latitude)) {
-    gpsData.SetLatitude(data->fix.latitude);
+    gpsData.SetLatitude(data->fix.latitude,data->fix.epy);
   }
 
   if ((data->set & LATLON_SET)  && !isnan(data->fix.longitude)) {
-    gpsData.SetLongitude(data->fix.longitude);
+    gpsData.SetLongitude(data->fix.longitude,data->fix.epx);
   }
 
   if ((data->set & ALTITUDE_SET) && !isnan(data->fix.altitude)) {
-    gpsData.SetAltitude(data->fix.altitude);
+    gpsData.SetAltitude(data->fix.altitude,data->fix.epv);
   }
 
   if ((data->set & SPEED_SET) && !isnan(data->fix.speed)) {
-    gpsData.SetSpeed(data->fix.speed); // m/s
+    gpsData.SetSpeed(data->fix.speed,data->fix.eps); // m/s
   }
 
   if ((data->set & TRACK_SET) && !isnan(data->fix.track)) {
-    gpsData.SetTrack(data->fix.track);
+    gpsData.SetTrack(data->fix.track,data->fix,epd);
   }
 
   if ((data->set & CLIMB_SET) && !isnan(data->fix.climb)) {
-    gpsData.SetClimb(data->fix.climb);
+    gpsData.SetClimb(data->fix.climb,data->fix.epc);
   }
 
   if (data->set & TIME_SET) {
     Lum::Base::SystemTime time(lround(data->fix.time));
-    gpsData.SetTime(time);
+    gpsData.SetTime(time,data->fix.ept);
   }
 
   if (data->set & SATELLITE_SET) {
@@ -1850,25 +1982,26 @@ static void gps_location_changed(LocationGPSDevice *device, gpointer userdata)
 
   if (fix->fields & LOCATION_GPS_DEVICE_TIME_SET) {
     Lum::Base::SystemTime time(lround(fix->time));
-    gpsData.SetTime(time);
+    gpsData.SetTime(time,fix->ept);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET && !isnan(fix->latitude)) {
-    gpsData.SetLatitude(fix->latitude);
+    gpsData.SetLatitude(fix->latitude,fix->eph);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET && !isnan(fix->longitude)) {
-    gpsData.SetLongitude(fix->longitude);
+    gpsData.SetLongitude(fix->longitude,fix->eph);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_ALTITUDE_SET && !isnan(fix->altitude)) {
-    gpsData.SetAltitude(fix->altitude);
+    gpsData.SetAltitude(fix->altitude,fix->epv);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_SPEED_SET && !isnan(fix->speed)) {
-    gpsData.SetSpeed(fix->speed*1000.0/3600); // km/h => m/s
+    gpsData.SetSpeed(fix->speed*1000.0/3600,
+                     fix->eps*1000.0/3600); // km/h => m/s
   }
   if (fix->fields & LOCATION_GPS_DEVICE_TRACK_SET && !isnan(fix->track)) {
-    gpsData.SetTrack(fix->track);
+    gpsData.SetTrack(fix->track,fix->epd);
   }
   if (fix->fields & LOCATION_GPS_DEVICE_CLIMB_SET && !isnan(fix->climb)) {
-    gpsData.SetClimb(fix->climb);
+    gpsData.SetClimb(fix->climb,fix->epc);
   }
 
   std::vector<GPSData::Satellite> satellites;
